@@ -1,10 +1,12 @@
 from .gk import GK
 from .bsketch import BSketch
 from .bsketch import BCatSketch
+from .binning_process_sketch import BinningProcessSketch
 from .binning_sketch import OptimalBinningSketch
 
 
 __all__ = ['BSketch',
            'BCatSketch',
            'GK',
-           'OptimalBinningSketch']
+           'OptimalBinningSketch',
+           'BinningProcessSketch']
